"use strict";

var _reducer = _interopRequireDefault(require("../reducer"));

var _constants = require("../constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('reducer', () => {
  it('should set fetching to true', () => {
    expect((0, _reducer.default)({}, {
      type: _constants.FETCHING,
      key: 'required'
    })).toHaveProperty('fetching', true);
  });
  it('should log fetching results', () => {
    const data = {
      resource: {
        foo: 'bar'
      }
    };
    expect((0, _reducer.default)({}, {
      type: _constants.FETCHED,
      key: 'foo',
      data
    })).toMatchObject({
      fetching: false,
      ...data
    });
  });
  it('should merge changes into state', () => {
    const data = {
      resource: {
        id: 1,
        name: 'bar'
      }
    };
    const prev = {
      resources: [{
        id: 1,
        name: 'foo'
      }]
    };
    expect((0, _reducer.default)(prev, {
      key: 'resource',
      pluralized: 'resources',
      type: _constants.UPDATED,
      data
    })).toMatchObject({ ...data,
      resources: [{
        id: 1,
        name: 'bar'
      }]
    });
  });
  it('should replace state on key match', () => {
    const data = {
      resource: [{
        id: 1,
        name: 'bar'
      }]
    };
    const prev = {
      resource: [{
        id: 1,
        name: 'foo'
      }, {
        id: 2,
        name: 'Hello'
      }]
    };
    expect((0, _reducer.default)(prev, {
      key: 'resource',
      pluralized: 'resources',
      type: _constants.UPDATED,
      data
    })).toMatchObject({ ...data,
      resource: [{
        id: 1,
        name: 'bar'
      }]
    });
  });
  it('should push into the state', () => {
    const data = {
      resource: {
        id: 2,
        name: 'bar'
      }
    };
    const prev = {
      resources: [{
        id: 1,
        name: 'foo'
      }]
    };
    expect((0, _reducer.default)(prev, {
      key: 'resource',
      pluralized: 'resources',
      type: _constants.CREATED,
      data
    })).toMatchObject(expect.objectContaining({
      resources: [data.resource, prev.resources[0]]
    }));
  });
  it('should delete from the state', () => {
    const data = {
      id: 1
    };
    const prev = {
      resources: [{
        id: 1,
        name: 'foo'
      }]
    };
    expect((0, _reducer.default)(prev, {
      key: 'resource',
      pluralized: 'resources',
      type: _constants.DELETED,
      data
    })).toMatchObject(expect.objectContaining({
      resources: []
    }));
  });
});